@@ -130,9 +130,9 @@ impl Proposal {
     }
 
     /// Gets the state.
-    pub fn get_state(&self, gov: &Governor) -> Result<ProposalState> {
+    pub fn get_state(&self) -> Result<ProposalState> {
         Ok(unwrap_opt!(
-            self.state(Clock::get()?.unix_timestamp, gov.params.quorum_votes),
+            self.state(Clock::get()?.unix_timestamp),
             "invalid state"
         ))
     }
@@ -150,14 +150,14 @@ impl Proposal {
 
     /// The state of the proposal. See [ProposalState] for more details.
     /// Adapted from <https://github.com/compound-finance/compound-protocol/blob/4a8648ec0364d24c4ecfc7d6cae254f55030d65f/contracts/Governance/GovernorBravoDelegate.sol#L205>
-    pub fn state(&self, current_time: i64, quorum_votes: u64) -> Option<ProposalState> {
+    pub fn state(&self, current_time: i64) -> Option<ProposalState> {
         if self.canceled_at > 0 {
             return Some(ProposalState::Canceled);
         } else if self.activated_at == 0 {
             return Some(ProposalState::Draft);
         } else if current_time < self.voting_ends_at {
             return Some(ProposalState::Active);
-        } else if self.for_votes <= self.against_votes || !self.meets_quorum(quorum_votes)? {
+        } else if self.for_votes <= self.against_votes || !self.meets_quorum(self.quorum_votes)? {
             return Some(ProposalState::Defeated);
         } else if self.queued_at > 0 {
             return Some(ProposalState::Queued);
@@ -295,10 +295,11 @@ mod tests {
             activated_at: t.activated_at,
             voting_ends_at: t.voting_ends_at,
             queued_at: t.queued_at,
+            quorum_votes: t.quorum_votes,
             ..Proposal::default()
         };
 
-        proposal.state(t.current_ts, t.quorum_votes).unwrap()
+        proposal.state(t.current_ts).unwrap()
     }
 
     #[test]
